summaryrefslogtreecommitdiff
path: root/TAO/tao/MProfile.h
diff options
context:
space:
mode:
authorfredk <fredk@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-02-24 17:09:17 +0000
committerfredk <fredk@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-02-24 17:09:17 +0000
commit0282c9f60b3a3fd0d91770b23e75b4a77a1a91f4 (patch)
tree41acd1258f728435deeee5fe95329486c0830fa9 /TAO/tao/MProfile.h
parent63f36ec7298bb69975291ea76c9ba927e3448bc3 (diff)
downloadATCD-0282c9f60b3a3fd0d91770b23e75b4a77a1a91f4.tar.gz
*** empty log message ***
Diffstat (limited to 'TAO/tao/MProfile.h')
-rw-r--r--TAO/tao/MProfile.h29
1 files changed, 11 insertions, 18 deletions
diff --git a/TAO/tao/MProfile.h b/TAO/tao/MProfile.h
index 43c63c366b6..64e3385dd07 100644
--- a/TAO/tao/MProfile.h
+++ b/TAO/tao/MProfile.h
@@ -97,19 +97,14 @@ public:
// Return the index of this entry or -1 if it can not be added.
// this object assumes ownership of this profile!!
- void fwded_mprofile (TAO_MProfile *mprofiles);
+ void forward_from (TAO_MProfile *mprofiles);
// @@ Fred, can you please change the name of this method to
// "forwarded_mprofile()"? In general, it's better to use complete
// names.
+ // Set a pointer to the MProfile whose 'current' TAO_Profile was forwarded
+ // This object is the set of forwarding profiles.
- // Set a pointer to the profile which was forwarded. NOTE, the
- // forwarding profile *MUST* be set at object creation. And it can
- // not be altered once it's set!
-
- TAO_MProfile *fwded_mprofile (void);
- // @@ Fred, can you please change the name of this method to
- // "forwarded_mprofile()"? In general, it's better to use complete
- // names.
+ TAO_MProfile *forward_from (void);
// Returns a pointer to the profile which was forwarded.
CORBA::Boolean is_equivalent (TAO_MProfile *first,
@@ -134,15 +129,13 @@ protected:
private:
- TAO_MProfile *fwded_mprofile_;
- // @@ Fred, can you please change all "fwded" to "forwarded"?
-
- // Used for chaining references when the current profile is
- // forwarded. Note, this will only be valid for an MProfile which
- // contains a list of fwd_profiles for some initial or base profile.
- // This is a backward reference to the profile list which received
- // the relocate message. The actual profile what was forwarded will
- // be fwded_mprofile_->get_current_profile ()
+ TAO_MProfile *forward_from_;
+ // Used for chaning references when the current profile is forwarded.
+ // Note, this will only be valid for an MProfile which contains a list of
+ // forward_profiles for some initial or base profile.
+ // This is a backward reference to the profile list which received the
+ // relocate message. The actual profile what was forwarded will be
+ // forward_from_->get_current_profile ()
TAO_Profile_ptr *pfiles_;
// Actual list of profiles.